@@ -22,7 +22,7 @@ ElementsType = Union[Collection[str], Collection[T], OrderedDictType[T, float]]
 class BaseProvider:
 
     __provider__ = "base"
-    __lang__ = None
+    __lang__: Optional[str] = None
     __use_weighting__ = False
 
     # Locales supported by Linux Mint from `/usr/share/i18n/SUPPORTED`
@@ -405,7 +405,7 @@ class BaseProvider:
 
     def random_elements(
         self,
-        elements: ElementsType[T] = ("a", "b", "c"),
+        elements: ElementsType[T] = ("a", "b", "c"),  # type: ignore[assignment]
         length: Optional[int] = None,
         unique: bool = False,
         use_weighting: Optional[bool] = None,
@@ -498,7 +498,11 @@ class BaseProvider:
             length=length,
         )
 
-    def random_choices(self, elements: ElementsType[T] = ("a", "b", "c"), length: Optional[int] = None) -> Sequence[T]:
+    def random_choices(
+        self,
+        elements: ElementsType[T] = ("a", "b", "c"),  # type: ignore[assignment]
+        length: Optional[int] = None,
+    ) -> Sequence[T]:
         """Generate a list of objects randomly sampled from ``elements`` with replacement.
 
         For information on the ``elements`` and ``length`` arguments, please refer to
@@ -541,7 +545,9 @@ class BaseProvider:
 
         return self.random_elements(elements, length=1)[0]
 
-    def random_sample(self, elements: ElementsType[T] = ("a", "b", "c"), length: Optional[int] = None) -> Sequence[T]:
+    def random_sample(
+        self, elements: ElementsType[T] = ("a", "b", "c"), length: Optional[int] = None  # type: ignore[assignment]
+    ) -> Sequence[T]:
         """Generate a list of objects randomly sampled from ``elements`` without replacement.
 
         For information on the ``elements`` and ``length`` arguments, please refer to
