@@ -4,12 +4,13 @@ import re
 
 from collections import OrderedDict
 from random import Random
-from typing import Any, Callable, Dict, Hashable, List, Optional, Pattern, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Pattern, Sequence, Tuple, Union
 
 from .config import DEFAULT_LOCALE
 from .exceptions import UniquenessException
 from .factory import Factory
-from .generator import Generator, Sentinel, random
+from .generator import Generator, random
+from .typing import SeedType
 from .utils.distribution import choices_distribution
 
 _UNIQUE_ATTEMPTS = 1000
@@ -152,8 +153,6 @@ class Faker:
         elif len(factories) == 1:
             return factories[0]
 
-        if Generator._global_seed is not Sentinel:
-            random.seed(Generator._global_seed)
         if weights:
             factory = self._select_factory_distribution(factories, weights)
         else:
@@ -200,7 +199,7 @@ class Faker:
         return mapping
 
     @classmethod
-    def seed(cls, seed: Optional[Hashable] = None) -> None:
+    def seed(cls, seed: Optional[SeedType] = None) -> None:
         """
         Hashables the shared `random.Random` object across all factories
 
@@ -208,7 +207,7 @@ class Faker:
         """
         Generator.seed(seed)
 
-    def seed_instance(self, seed: Optional[Hashable] = None) -> None:
+    def seed_instance(self, seed: Optional[SeedType] = None) -> None:
         """
         Creates and seeds a new `random.Random` object for each factory
 
@@ -217,7 +216,7 @@ class Faker:
         for factory in self._factories:
             factory.seed_instance(seed)
 
-    def seed_locale(self, locale: str, seed: Optional[Hashable] = None) -> None:
+    def seed_locale(self, locale: str, seed: Optional[SeedType] = None) -> None:
         """
         Creates and seeds a new `random.Random` object for the factory of the specified locale
 
